# Some collection used for unit testing mazer

The rest of this README does not have useful info.

## Random Facts

"War of the ants" was a phrase used to describe TV static in Europe and elsewhere.

## Useless Info

If you watch the opening of 'Star Trek TOS/TNG' while listening to
Chuck Mangione's "Feels So Good" it becomes an episode of 'The Love Boat'.

## Quotes That Likely Never Make Sense In Context

"so that game's kinda not feasible these days. especially because they moved the bojangles.
now bojangles is right in the way."
-- Jon Bois (July 2017) - _17776: What Football Will Look Like in the Future_ - https://www.sbnation.com/a/17776-football
